public inbox for gdb-cvs@sourceware.org
help / color / mirror / Atom feed
* [binutils-gdb] Rename print_spaces_filtered
@ 2022-03-29 19:43 Tom Tromey
  0 siblings, 0 replies; only message in thread
From: Tom Tromey @ 2022-03-29 19:43 UTC (permalink / raw)
  To: gdb-cvs

https://sourceware.org/git/gitweb.cgi?p=binutils-gdb.git;h=d0b1020bf1f9f0e3824d61cd3821e3ea7773f828

commit d0b1020bf1f9f0e3824d61cd3821e3ea7773f828
Author: Tom Tromey <tom@tromey.com>
Date:   Sun Jan 2 11:53:15 2022 -0700

    Rename print_spaces_filtered
    
    print_spaces_filtered is now misnamed, because whether filtering
    happens is up to the stream.  So, rename it.

Diff:
---
 gdb/ada-valprint.c           | 10 +++++-----
 gdb/c-typeprint.c            | 14 +++++++-------
 gdb/c-valprint.c             |  2 +-
 gdb/cli-out.c                |  2 +-
 gdb/cp-valprint.c            |  8 ++++----
 gdb/guile/scm-pretty-print.c |  6 +++---
 gdb/m2-typeprint.c           |  2 +-
 gdb/p-typeprint.c            |  4 ++--
 gdb/p-valprint.c             | 10 +++++-----
 gdb/python/py-prettyprint.c  |  6 +++---
 gdb/riscv-tdep.c             |  2 +-
 gdb/rust-lang.c              | 12 ++++++------
 gdb/symmisc.c                |  2 +-
 gdb/typeprint.c              |  4 ++--
 gdb/utils.c                  |  2 +-
 gdb/utils.h                  |  2 +-
 gdb/valprint.c               |  6 +++---
 17 files changed, 47 insertions(+), 47 deletions(-)

diff --git a/gdb/ada-valprint.c b/gdb/ada-valprint.c
index 2db311110a3..ed0ce56bca5 100644
--- a/gdb/ada-valprint.c
+++ b/gdb/ada-valprint.c
@@ -166,7 +166,7 @@ val_print_packed_array_elements (struct type *type, const gdb_byte *valaddr,
 	  if (options->prettyformat_arrays)
 	    {
 	      gdb_printf (stream, ",\n");
-	      print_spaces_filtered (2 + 2 * recurse, stream);
+	      print_spaces (2 + 2 * recurse, stream);
 	    }
 	  else
 	    {
@@ -176,7 +176,7 @@ val_print_packed_array_elements (struct type *type, const gdb_byte *valaddr,
       else if (options->prettyformat_arrays)
 	{
 	  gdb_printf (stream, "\n");
-	  print_spaces_filtered (2 + 2 * recurse, stream);
+	  print_spaces (2 + 2 * recurse, stream);
 	}
       stream->wrap_here (2 + 2 * recurse);
       maybe_print_array_index (index_type, i + low, stream, options);
@@ -229,7 +229,7 @@ val_print_packed_array_elements (struct type *type, const gdb_byte *valaddr,
 		  if (options->prettyformat_arrays)
 		    {
 		      gdb_printf (stream, ",\n");
-		      print_spaces_filtered (2 + 2 * recurse, stream);
+		      print_spaces (2 + 2 * recurse, stream);
 		    }
 		  else
 		    {
@@ -621,7 +621,7 @@ print_field_values (struct value *value, struct value *outer_value,
       if (options->prettyformat)
 	{
 	  gdb_printf (stream, "\n");
-	  print_spaces_filtered (2 + 2 * recurse, stream);
+	  print_spaces (2 + 2 * recurse, stream);
 	}
       else
 	{
@@ -887,7 +887,7 @@ ada_val_print_struct_union (struct value *value,
       && options->prettyformat)
     {
       gdb_printf (stream, "\n");
-      print_spaces_filtered (2 * recurse, stream);
+      print_spaces (2 * recurse, stream);
     }
 
   gdb_printf (stream, ")");
diff --git a/gdb/c-valprint.c b/gdb/c-valprint.c
index 9a860bfc94a..93e7cfd4254 100644
--- a/gdb/c-valprint.c
+++ b/gdb/c-valprint.c
@@ -222,7 +222,7 @@ print_unpacked_pointer (struct type *type, struct type *elttype,
 	  if (options->prettyformat)
 	    {
 	      gdb_printf (stream, "\n");
-	      print_spaces_filtered (2 + 2 * recurse, stream);
+	      print_spaces (2 + 2 * recurse, stream);
 	    }
 	}
     }
diff --git a/gdb/cli-out.c b/gdb/cli-out.c
index f396aef12e3..39279d96397 100644
--- a/gdb/cli-out.c
+++ b/gdb/cli-out.c
@@ -211,7 +211,7 @@ cli_ui_out::do_spaces (int numspaces)
   if (test_flags (unfiltered_output))
     gdb_printf (m_streams.back (), "%*s", numspaces, "");
   else
-    print_spaces_filtered (numspaces, m_streams.back ());
+    print_spaces (numspaces, m_streams.back ());
 }
 
 void
diff --git a/gdb/cp-valprint.c b/gdb/cp-valprint.c
index 92b5f440e76..fc5600c100c 100644
--- a/gdb/cp-valprint.c
+++ b/gdb/cp-valprint.c
@@ -207,7 +207,7 @@ cp_print_value_fields (struct value *val, struct ui_file *stream,
 	      if (options->prettyformat)
 		{
 		  gdb_printf (stream, "\n");
-		  print_spaces_filtered (2 + 2 * recurse, stream);
+		  print_spaces (2 + 2 * recurse, stream);
 		  gdb_puts ("members of ", stream);
 		  gdb_puts (type->name (), stream);
 		  gdb_puts (":", stream);
@@ -218,7 +218,7 @@ cp_print_value_fields (struct value *val, struct ui_file *stream,
 	  if (options->prettyformat)
 	    {
 	      gdb_printf (stream, "\n");
-	      print_spaces_filtered (2 + 2 * recurse, stream);
+	      print_spaces (2 + 2 * recurse, stream);
 	    }
 	  else
 	    {
@@ -374,7 +374,7 @@ cp_print_value_fields (struct value *val, struct ui_file *stream,
       if (options->prettyformat)
 	{
 	  gdb_printf (stream, "\n");
-	  print_spaces_filtered (2 * recurse, stream);
+	  print_spaces (2 * recurse, stream);
 	}
     }				/* if there are data fields */
 
@@ -479,7 +479,7 @@ cp_print_value (struct value *val, struct ui_file *stream,
       if (options->prettyformat)
 	{
 	  gdb_printf (stream, "\n");
-	  print_spaces_filtered (2 * recurse, stream);
+	  print_spaces (2 * recurse, stream);
 	}
       gdb_puts ("<", stream);
       /* Not sure what the best notation is in the case where there is
diff --git a/gdb/guile/scm-pretty-print.c b/gdb/guile/scm-pretty-print.c
index a99ab13c1d8..2bb63e849d1 100644
--- a/gdb/guile/scm-pretty-print.c
+++ b/gdb/guile/scm-pretty-print.c
@@ -858,7 +858,7 @@ ppscm_print_children (SCM printer, enum display_hint hint,
 	  if (pretty)
 	    {
 	      gdb_puts ("\n", stream);
-	      print_spaces_filtered (2 + 2 * recurse, stream);
+	      print_spaces (2 + 2 * recurse, stream);
 	    }
 	  else
 	    stream->wrap_here (2 + 2 *recurse);
@@ -930,14 +930,14 @@ ppscm_print_children (SCM printer, enum display_hint hint,
 	  if (pretty)
 	    {
 	      gdb_puts ("\n", stream);
-	      print_spaces_filtered (2 + 2 * recurse, stream);
+	      print_spaces (2 + 2 * recurse, stream);
 	    }
 	  gdb_puts ("...", stream);
 	}
       if (pretty)
 	{
 	  gdb_puts ("\n", stream);
-	  print_spaces_filtered (2 * recurse, stream);
+	  print_spaces (2 * recurse, stream);
 	}
       gdb_puts ("}", stream);
     }
diff --git a/gdb/m2-typeprint.c b/gdb/m2-typeprint.c
index ae0a879f12a..cbd35df0190 100644
--- a/gdb/m2-typeprint.c
+++ b/gdb/m2-typeprint.c
@@ -562,7 +562,7 @@ m2_record_fields (struct type *type, struct ui_file *stream, int show,
 	{
 	  QUIT;
 
-	  print_spaces_filtered (level + 4, stream);
+	  print_spaces (level + 4, stream);
 	  fputs_styled (type->field (i).name (),
 			variable_name_style.style (), stream);
 	  gdb_puts (" : ", stream);
diff --git a/gdb/p-typeprint.c b/gdb/p-typeprint.c
index 0ef8c922606..f222f01b429 100644
--- a/gdb/p-typeprint.c
+++ b/gdb/p-typeprint.c
@@ -561,7 +561,7 @@ pascal_language::type_print_base (struct type *type, struct ui_file *stream, int
 		    }
 		}
 
-	      print_spaces_filtered (level + 4, stream);
+	      print_spaces (level + 4, stream);
 	      if (field_is_static (&type->field (i)))
 		gdb_printf (stream, "static ");
 	      print_type (type->field (i).type (),
@@ -633,7 +633,7 @@ pascal_language::type_print_base (struct type *type, struct ui_file *stream, int
 			}
 		    }
 
-		  print_spaces_filtered (level + 4, stream);
+		  print_spaces (level + 4, stream);
 		  if (TYPE_FN_FIELD_STATIC_P (f, j))
 		    gdb_printf (stream, "static ");
 		  if (TYPE_TARGET_TYPE (TYPE_FN_FIELD_TYPE (f, j)) == 0)
diff --git a/gdb/p-valprint.c b/gdb/p-valprint.c
index 926b0f1aa57..3b98b88b528 100644
--- a/gdb/p-valprint.c
+++ b/gdb/p-valprint.c
@@ -267,7 +267,7 @@ pascal_language::value_print_inner (struct value *val,
 	      if (options->prettyformat)
 		{
 		  gdb_printf (stream, "\n");
-		  print_spaces_filtered (2 + 2 * recurse, stream);
+		  print_spaces (2 + 2 * recurse, stream);
 		}
 	    }
 	}
@@ -559,7 +559,7 @@ pascal_object_print_value_fields (struct value *val, struct ui_file *stream,
 	      if (options->prettyformat)
 		{
 		  gdb_printf (stream, "\n");
-		  print_spaces_filtered (2 + 2 * recurse, stream);
+		  print_spaces (2 + 2 * recurse, stream);
 		  gdb_puts ("members of ", stream);
 		  gdb_puts (type->name (), stream);
 		  gdb_puts (": ", stream);
@@ -570,7 +570,7 @@ pascal_object_print_value_fields (struct value *val, struct ui_file *stream,
 	  if (options->prettyformat)
 	    {
 	      gdb_printf (stream, "\n");
-	      print_spaces_filtered (2 + 2 * recurse, stream);
+	      print_spaces (2 + 2 * recurse, stream);
 	    }
 	  else
 	    {
@@ -671,7 +671,7 @@ pascal_object_print_value_fields (struct value *val, struct ui_file *stream,
       if (options->prettyformat)
 	{
 	  gdb_printf (stream, "\n");
-	  print_spaces_filtered (2 * recurse, stream);
+	  print_spaces (2 * recurse, stream);
 	}
     }
   gdb_printf (stream, "}");
@@ -762,7 +762,7 @@ pascal_object_print_value (struct value *val, struct ui_file *stream,
       if (options->prettyformat)
 	{
 	  gdb_printf (stream, "\n");
-	  print_spaces_filtered (2 * recurse, stream);
+	  print_spaces (2 * recurse, stream);
 	}
       gdb_puts ("<", stream);
       /* Not sure what the best notation is in the case where there is no
diff --git a/gdb/python/py-prettyprint.c b/gdb/python/py-prettyprint.c
index a88a9f5b9b6..c9bbd726412 100644
--- a/gdb/python/py-prettyprint.c
+++ b/gdb/python/py-prettyprint.c
@@ -471,7 +471,7 @@ print_children (PyObject *printer, const char *hint,
 	  if (pretty)
 	    {
 	      gdb_puts ("\n", stream);
-	      print_spaces_filtered (2 + 2 * recurse, stream);
+	      print_spaces (2 + 2 * recurse, stream);
 	    }
 	  else
 	    stream->wrap_here (2 + 2 *recurse);
@@ -550,14 +550,14 @@ print_children (PyObject *printer, const char *hint,
 	  if (pretty)
 	    {
 	      gdb_puts ("\n", stream);
-	      print_spaces_filtered (2 + 2 * recurse, stream);
+	      print_spaces (2 + 2 * recurse, stream);
 	    }
 	  gdb_puts ("...", stream);
 	}
       if (pretty)
 	{
 	  gdb_puts ("\n", stream);
-	  print_spaces_filtered (2 * recurse, stream);
+	  print_spaces (2 * recurse, stream);
 	}
       gdb_puts ("}", stream);
     }
diff --git a/gdb/riscv-tdep.c b/gdb/riscv-tdep.c
index 8d1ecf0cdd7..e569f9369b8 100644
--- a/gdb/riscv-tdep.c
+++ b/gdb/riscv-tdep.c
@@ -1038,7 +1038,7 @@ riscv_print_one_register_info (struct gdbarch *gdbarch,
   enum tab_stops { value_column_1 = 15 };
 
   gdb_puts (name, file);
-  print_spaces_filtered (value_column_1 - strlen (name), file);
+  print_spaces (value_column_1 - strlen (name), file);
 
   try
     {
diff --git a/gdb/rust-lang.c b/gdb/rust-lang.c
index 45a6d2f7f1d..836ea37f153 100644
--- a/gdb/rust-lang.c
+++ b/gdb/rust-lang.c
@@ -372,7 +372,7 @@ rust_language::val_print_struct
       if (options->prettyformat)
 	{
 	  gdb_puts ("\n", stream);
-	  print_spaces_filtered (2 + 2 * recurse, stream);
+	  print_spaces (2 + 2 * recurse, stream);
 	}
       else if (!first_field)
 	gdb_puts (" ", stream);
@@ -393,7 +393,7 @@ rust_language::val_print_struct
   if (options->prettyformat)
     {
       gdb_puts ("\n", stream);
-      print_spaces_filtered (2 * recurse, stream);
+      print_spaces (2 * recurse, stream);
     }
 
   if (is_tuple || is_tuple_struct)
@@ -707,7 +707,7 @@ rust_print_struct_def (struct type *type, const char *varstring,
       /* For a tuple struct we print the type but nothing
 	 else.  */
       if (!for_rust_enum || flags->print_offsets)
-	print_spaces_filtered (level + 2, stream);
+	print_spaces (level + 2, stream);
       if (is_enum)
 	fputs_styled (type->field (i).name (), variable_name_style.style (),
 		      stream);
@@ -733,12 +733,12 @@ rust_print_struct_def (struct type *type, const char *varstring,
       /* Undo the temporary level increase we did above.  */
       level -= 2;
       podata->finish (type, level, stream);
-      print_spaces_filtered (print_offset_data::indentation, stream);
+      print_spaces (print_offset_data::indentation, stream);
       if (level == 0)
-	print_spaces_filtered (2, stream);
+	print_spaces (2, stream);
     }
   if (!for_rust_enum || flags->print_offsets)
-    print_spaces_filtered (level, stream);
+    print_spaces (level, stream);
   gdb_puts (is_tuple_struct ? ")" : "}", stream);
 }
 
diff --git a/gdb/symmisc.c b/gdb/symmisc.c
index 8de20d647f3..37ecc8064da 100644
--- a/gdb/symmisc.c
+++ b/gdb/symmisc.c
@@ -507,7 +507,7 @@ print_symbol (struct gdbarch *gdbarch, struct symbol *symbol,
   else
     section = NULL;
 
-  print_spaces_filtered (depth, outfile);
+  print_spaces (depth, outfile);
   if (symbol->domain () == LABEL_DOMAIN)
     {
       gdb_printf (outfile, "label %s at ", symbol->print_name ());
diff --git a/gdb/typeprint.c b/gdb/typeprint.c
index 7acddd8f4b7..3356bdde2e7 100644
--- a/gdb/typeprint.c
+++ b/gdb/typeprint.c
@@ -127,7 +127,7 @@ print_offset_data::update (struct type *type, unsigned int field_idx,
 {
   if (field_is_static (&type->field (field_idx)))
     {
-      print_spaces_filtered (indentation, stream);
+      print_spaces (indentation, stream);
       return;
     }
 
@@ -188,7 +188,7 @@ print_offset_data::finish (struct type *type, int level,
   maybe_print_hole (stream, bitpos, "padding");
 
   gdb_puts ("\n", stream);
-  print_spaces_filtered (level + 4 + print_offset_data::indentation, stream);
+  print_spaces (level + 4 + print_offset_data::indentation, stream);
   gdb_printf (stream, "/* total size (bytes): %4s */\n",
 	      pulongest (TYPE_LENGTH (type)));
 }
diff --git a/gdb/utils.c b/gdb/utils.c
index 9175b006451..e358a5a560d 100644
--- a/gdb/utils.c
+++ b/gdb/utils.c
@@ -1907,7 +1907,7 @@ n_spaces (int n)
 
 /* Print N spaces.  */
 void
-print_spaces_filtered (int n, struct ui_file *stream)
+print_spaces (int n, struct ui_file *stream)
 {
   gdb_puts (n_spaces (n), stream);
 }
diff --git a/gdb/utils.h b/gdb/utils.h
index 79f53c4edab..981090e3019 100644
--- a/gdb/utils.h
+++ b/gdb/utils.h
@@ -255,7 +255,7 @@ extern void gdb_printf (const char *, ...) ATTRIBUTE_PRINTF (1, 2);
 
 extern void printf_unfiltered (const char *, ...) ATTRIBUTE_PRINTF (1, 2);
 
-extern void print_spaces_filtered (int, struct ui_file *);
+extern void print_spaces (int, struct ui_file *);
 
 extern const char *n_spaces (int);
 
diff --git a/gdb/valprint.c b/gdb/valprint.c
index 7cdf6103326..9990d432e35 100644
--- a/gdb/valprint.c
+++ b/gdb/valprint.c
@@ -1929,7 +1929,7 @@ value_print_array_elements (struct value *val, struct ui_file *stream,
 	  if (options->prettyformat_arrays)
 	    {
 	      gdb_printf (stream, ",\n");
-	      print_spaces_filtered (2 + 2 * recurse, stream);
+	      print_spaces (2 + 2 * recurse, stream);
 	    }
 	  else
 	    gdb_printf (stream, ", ");
@@ -1937,7 +1937,7 @@ value_print_array_elements (struct value *val, struct ui_file *stream,
       else if (options->prettyformat_arrays)
 	{
 	  gdb_printf (stream, "\n");
-	  print_spaces_filtered (2 + 2 * recurse, stream);
+	  print_spaces (2 + 2 * recurse, stream);
 	}
       stream->wrap_here (2 + 2 * recurse);
       maybe_print_array_index (index_type, i + low_bound,
@@ -1985,7 +1985,7 @@ value_print_array_elements (struct value *val, struct ui_file *stream,
   if (options->prettyformat_arrays)
     {
       gdb_printf (stream, "\n");
-      print_spaces_filtered (2 * recurse, stream);
+      print_spaces (2 * recurse, stream);
     }
 }


^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2022-03-29 19:43 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2022-03-29 19:43 [binutils-gdb] Rename print_spaces_filtered Tom Tromey

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).
diff --git a/gdb/c-typeprint.c b/gdb/c-typeprint.c
index 6b537160fbc..66fea58cbbb 100644
--- a/gdb/c-typeprint.c
+++ b/gdb/c-typeprint.c
@@ -906,7 +906,7 @@ c_type_print_template_args (const struct type_print_options *flags,
     gdb_puts (_("] "), stream);
 }
 
 /* Use 'print_spaces_filtered', but take into consideration the
    type_print_options FLAGS in order to determine how many whitespaces
    will be printed.  */
 
@@ -915,9 +915,9 @@ print_spaces_filtered_with_print_options
   (int level, struct ui_file *stream, const struct type_print_options *flags)
 {
   if (!flags->print_offsets)
-    print_spaces_filtered (level, stream);
+    print_spaces (level, stream);
   else
-    print_spaces_filtered (level + print_offset_data::indentation, stream);
+    print_spaces (level + print_offset_data::indentation, stream);
 }
 
 /* Output an access specifier to STREAM, if needed.  LAST_ACCESS is the
@@ -1175,7 +1175,7 @@ c_type_print_base_struct_union (struct type *type, struct ui_file *stream,
 	  if (flags->print_offsets)
 	    podata->update (type, i, stream);
 
-	  print_spaces_filtered (level + 4, stream);
+	  print_spaces (level + 4, stream);
 	  if (is_static)
 	    gdb_printf (stream, "static ");
 
@@ -1426,9 +1426,9 @@ c_type_print_base_struct_union (struct type *type, struct ui_file *stream,
 	  if (show > 0)
 	    podata->finish (type, level, stream);
 
-	  print_spaces_filtered (print_offset_data::indentation, stream);
+	  print_spaces (print_offset_data::indentation, stream);
 	  if (level == 0)
-	    print_spaces_filtered (2, stream);
+	    print_spaces (2, stream);
 	}
 
       gdb_printf (stream, "%*s}", level, "");
@@ -1639,7 +1639,7 @@ c_type_print_base_1 (struct type *type, struct ui_file *stream,
 	    for (i = 0; i < len; i++)
 	      {
 		QUIT;
-		print_spaces_filtered (level + 4, stream);
+		print_spaces (level + 4, stream);
 		/* We pass "show" here and not "show - 1" to get enum types
 		   printed.  There's no other way to see them.  */
 		c_print_type_1 (type->field (i).type (),
@@ -906,7 +906,7 @@ c_type_print_template_args (const struct type_print_options *flags,
 }
 
-/* Use 'print_spaces_filtered', but take into consideration the
+/* Use 'print_spaces', but take into consideration the
    type_print_options FLAGS in order to determine how many whitespaces
    will be printed.  */